import 'package:core_location_fluttify/core_location_fluttify.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'options.dart';

/// 地图标记
abstract class IMarker {
  /// 获取标题
  Future<String> get title;

  /// 获取副标题
  Future<String> get snippet;

  /// 获取定位信息
  Future<LatLng> get location;

  /// 获取自定义信息
  Future<String> get object;

  /// 删除marker
  Future<void> remove() => throw UnimplementedError();

  /// 设置坐标
  Future<void> setCoordinate(LatLng coordinate) => throw UnimplementedError();

  /// 设置可见性
  Future<void> setVisible(bool visible) => throw UnimplementedError();

  /// 显示弹窗
  Future<void> showInfoWindow() => throw UnimplementedError();

  /// 关闭弹窗
  Future<void> hideInfoWindow() => throw UnimplementedError();

  /// 设置图标
  Future<void> setIcon(
    ImageProvider iconProvider,
    ImageConfiguration configuration,
  ) =>
      throw UnimplementedError();

  /// 设置动画
  Future<void> startAnimation(MarkerAnimation animation) =>
      throw UnimplementedError();
}

/// 平滑移动点
abstract class ISmoothMoveMarker {
  Future<void> remove() => throw UnimplementedError();

  Future<void> stop() => throw UnimplementedError();
}

/// 折线
abstract class IPolyline {
  Future<void> remove() => throw UnimplementedError();

  /// 重新设置折线点列表
  ///
  /// 可用于轨迹记录
  Future<void> setCoordinateList(List<LatLng> coordinateList) =>
      throw UnimplementedError();
}

/// 多边形
abstract class IPolygon {
  Future<void> remove() {
    throw UnimplementedError();
  }

  Future<bool> contains(LatLng target) => throw UnimplementedError();
}

/// 圆形
abstract class ICircle {
  Future<void> remove() => throw UnimplementedError();
}

/// 热力图
abstract class IHeatmapOverlay {
  Future<void> remove() => throw UnimplementedError();
}

/// 热力图
abstract class IUrlTileOverlay {
  Future<void> remove() => throw UnimplementedError();
}

/// 图片覆盖物
abstract class IGroundOverlay {
  Future<void> remove() => throw UnimplementedError();
}

/// 海量点
abstract class IMultiPointOverlay {
  Future<void> remove() => throw UnimplementedError();
}

/// 回放轨迹
abstract class IPlaybackTrace {
  Future<void> remove() => throw UnimplementedError();

  Future<void> stop() => throw UnimplementedError();
}
